@@ -37,7 +37,13 @@ sub _http_request{
             if($self->ua_debug){
                 $self->print("-- Non-blocking request (@{[$tx->req->url->to_abs]})\n");
                 $self->print("-- Client >>> Server (@{[$tx->req->url->to_abs]})\n@{[$tx->req->to_string]}\n");
-                $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->to_string]}\n");
+                my $content_type = eval {$tx->res->headers->content_type};
+                if(defined $content_type and $content_type =~m#^image/|^application/octet-stream#){
+                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->build_start_line . $tx->res->build_headers]}\n");
+                }
+                else{
+                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->to_string]}\n");
+                }
             }
             $self->save_cookie();
             if(defined $tx and $tx->success){
@@ -61,7 +67,13 @@ sub _http_request{
             if($self->ua_debug){
                 $self->print("-- Blocking request (@{[$tx->req->url->to_abs]})\n");
                 $self->print("-- Client >>> Server (@{[$tx->req->url->to_abs]})\n@{[$tx->req->to_string]}\n");
-                $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->to_string]}\n");
+                my $content_type = eval {$tx->res->headers->content_type};
+                if(defined $content_type and $content_type =~m#^image/|^application/octet-stream#){
+                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->build_start_line . $tx->res->build_headers]}\n");
+                }
+                else{
+                    $self->print("-- Server >>> Client (@{[$tx->req->url->to_abs]})\n@{[$tx->res->to_string]}\n");
+                }
             }
             $self->save_cookie();
             if(defined $tx and $tx->success){
@@ -87,28 +99,31 @@ sub _http_request{
 sub load_cookie{
     my $self = shift;
     return if not $self->keep_cookie;
-    if(not defined $self->qq){
-        $self->warn("未设置登录帐号, 无法加载登录cookie"); 
-        return;  
-    }
+    #if(not defined $self->qq){
+    #    $self->warn("未设置登录帐号, 无法加载登录cookie"); 
+    #    return;  
+    #}
     my $cookie_jar;
-    my $cookie_path = File::Spec->catfile($self->cookie_dir , 'mojo_webqq_cookie_' . $self->qq . '.dat');
+    my $cookie_path = File::Spec->catfile($self->cookie_dir , 'mojo_webqq_cookie_' . ($self->is_set_qq && $self->qq?$self->qq:'default') . '.dat');
     return if not -f $cookie_path;
     eval{require Storable;$cookie_jar = Storable::retrieve($cookie_path)};
     if($@){
-        $self->warn("客户端加载cookie失败: $@");
+        $self->warn("客户端加载cookie[ $cookie_path ]失败: $@");
         return;
     }
+    else{
+        $self->debug("客户端加载cookie[ $cookie_path ]");
+    }
     $self->ua->cookie_jar($cookie_jar);
 
 }
 sub save_cookie{
     my $self = shift;
     return if not $self->keep_cookie;
-    return if not defined $self->qq;
-    my $cookie_path = File::Spec->catfile($self->cookie_dir ,'mojo_webqq_cookie_' .$self->qq . '.dat');
+    #return if not defined $self->qq;
+    my $cookie_path = File::Spec->catfile($self->cookie_dir ,'mojo_webqq_cookie_' .($self->is_set_qq && $self->qq?$self->qq:'default') . '.dat');
     eval{Storable::nstore($self->ua->cookie_jar,$cookie_path);};
-    $self->warn("客户端保存cookie失败: $@") if $@;
+    $self->warn("客户端保存cookie[ $cookie_path ]失败: $@") if $@;
 }
 
 sub search_cookie{
